@@ -1,8 +1,7 @@
-package Pcore::API::Moz v0.4.2;
+package Pcore::API::Moz v0.5.0;
 
-use Pcore -dist, -class;
-use Pcore::API::Response;
-use Digest::HMAC_SHA1 qw[];
+use Pcore -dist, -class, -status;
+use Pcore::Util::Digest qw[hmac_sha1];
 use Pcore::HTTP::CookieJar;
 
 has api_id      => ( is => 'ro', isa => Str,         required => 1 );
@@ -53,7 +52,7 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
         Cols     => $metric,
     };
 
-    $url_params->{Signature} = P->data->to_b64( Digest::HMAC_SHA1::hmac_sha1( $url_params->{AccessID} . $LF . $url_params->{Expires}, $self->api_key ) );
+    $url_params->{Signature} = P->data->to_b64( hmac_sha1( $url_params->{AccessID} . $LF . $url_params->{Expires}, $self->api_key ) );
 
     my $url = 'https://lsapi.seomoz.com/linkscape/url-metrics/?' . P->data->to_uri($url_params);
 
@@ -70,16 +69,16 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
                 my $api_res;
 
                 if ( $res->status != 200 ) {
-                    $api_res = Pcore::API::Response->new( { status => $res->status, reason => $res->reason } );
+                    $api_res = status [ $res->status, $res->reason ];
                 }
                 else {
                     my $json = eval { P->data->from_json( $res->body->$* ); };
 
                     if ($@) {
-                        $api_res = Pcore::API::Response->new( { status => 999, reason => 'Invalid JSON body' } );
+                        $api_res = status [ 999, 'Invalid JSON body' ];
                     }
                     else {
-                        $api_res = Pcore::API::Response->new( { status => 200 } );
+                        $api_res = status 200;
 
                         for my $i ( 0 .. $domains->$#* ) {
                             $api_res->{result}->{ $domains->[$i] } = $json->[$i];
@@ -119,7 +118,7 @@ sub url_metrics ( $self, $domains, $metric, $cb ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 22                   | ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     |
+## |    2 | 21                   | ValuesAndExpressions::RequireNumberSeparators - Long number not separated with underscores                     |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
